==> DSA_1.0.tar.gz: DSA/src/dsa.h <==
#define epsiloncompare 1e-8
#define GLOBALg02tol 1e-6 
#define DSA_PACK_Mbase 0
#define DSA_PACK_Mlow 1
#define DSA_PACK_Mmedium 2
#define DSA_PACK_Mhigh 3
#define abs(a) (((a)>0)?(a):(-(a)))
#define max(a,b) (((a)>(b))?(a):(b))

#ifndef __HAS_userMlevel__ 
#define __HAS_userMlevel__ 

int DSA_PACK_userMlevel;

#endif 

void DSA_PACK_printmatrix(double *x, int nrow, int ncol);
void DSA_PACK_printmatrixl(int *x, int nrow, int ncol);
void DSA_PACK_printmatrix_to_file(double *x, int nrow, int ncol, char* f);

double DSA_PACK_getmin(double *x,int n);
void DSA_PACK_initialize_l(int *x,int n);
void DSA_PACK_initialize_d(double *x,int n);
int DSA_PACK_rowsumints(int *x,int nrow,int ncol,int whichrow);
int DSA_PACK_num_nonzero(int *x,int n);
int DSA_PACK_sumofints(int *x,int n);


void DSA_PACK_startAlgo(double *glmWT,double *PARA,double *SE,double *COV,
			double *RES,int *gCOUNT,int *gCONST,double *bestarss, double *Ydata, double *Xdata,
			int *sx,int **bestmodels,int *currentmodel,int *tempmodel,int *nextmodel,int *newterm,
			int *ithterm,double *tempterm,double *tempXdata,double *tempYdata,double *WTdata,
			int trainFlag,double *currentarss,int *nforced, int *forcedterms,
			double* new_coefficients,
			double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot);
		       

void DSA_PACK_getaverageCVrisks(int *gCOUNT,int *gCONST,int *sx,double *Xtrain,double *Ytrain,double *Xval,
				double *Yval,int **bestmodels,double *tempXtrain,double *tempYtrain,
				double *tempXval,double *tempYval,double *temptermtrain,
				double *temptermval,double *PARA,double *SE,double *COV,double *RES,
				double *glmWT,double *CVrisksbysplit,
				double *WTtrain,double *WTval,int nforced,int *tempmodel,
				double* new_coefficients,
				double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot);

int DSA_PACK_Sstep(int *gCOUNT,int *gCONST,double *bestarss,int **bestmodels,int *tempmodel,int *currentmodel,
		   int *nextmodel,int *newterm,double *Xdata,double *tempXdata,double *Ydata,double *tempYdata,
		   double *tempterm,int *sx,double *glmWT,double *PARA,double *SE,double *COV,
		   double *RES,int *ithterm,double *WTdata,int trainFlag,double *currentarss, int nforced,
		   double* new_coefficients,
		   double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot
		   );

int DSA_PACK_Astep(int *gCOUNT,int *gCONST,double *bestarss,int **bestmodels,int *tempmodel,int *currentmodel,
		   int *nextmodel,int *newterm,double *Xdata,double *tempXdata,double *Ydata,double *tempYdata,
		   double *tempterm,int *sx,double *glmWT,double *PARA,double *SE,double *COV,
		   double *RES,int *ithterm,double *WTdata,int trainFlag,double *currentarss,
		   double* new_coefficients,
		   double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot
		   );

int DSA_PACK_Dstep(int *gCOUNT,int *gCONST,double *bestarss,int **bestmodels,int *tempmodel,int *currentmodel,
		   int *nextmodel,int *newterm,double *Xdata,double *tempXdata,double *Ydata,double *tempYdata,
		   double *tempterm,int *sx,double *glmWT,double *PARA,double *SE,double *COV,
		   double *RES,double *WTdata,int trainFlag,double *currentarss,
		   int nforced,
		   double* new_coefficients,
		   double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot
		   );

void DSA_PACK_gettempXdata(int msize,int *tempmodel, int maxsize, int nvarX, int samplesize, double *tempXdata, 
			   double *Xdata, double *tempterm,double *tempYdata,double *Ydata);


void DSA_PACK_evaluatenewmodel(int *sx,int maxsize,int msize,int *tempmodel,int newterm_index,
			       int *changeindexset,int nvarX, int samplesize,double *tempXdata,
			       double *Xdata,double *tempterm, int CENSOR,double *glmWT,double *WTdata, 
			       int IP,double *tempYdata,double *Ydata,double *PARA,double *SE,double *COV,
			       double *RES, int *nglmcall, double *newrss,int *nextmodel,int inddel,int binind,
			       double* new_coefficients,
			       double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot);



void DSA_PACK_checknewterm(int *orderint_in_newterm,int *sumofpow_in_newterm,int *is_newterm_unique,
			   int *newterm,int nvarX,int *tempmodel,int *ithterm,int maxsize,int newterm_index,
			   int addmove_notsubmove);

int DSA_PACK_istermunique(int *newterm,int *tempmodel,int *ithterm,int maxsize,int nvarX,int newterm_index,
			  int addmove_notsubmove,int orderint_in_newterm, int sumofpow_in_newterm);

int DSA_PACK_exportresult(double *oldrss,double newrss,int msize,int nvarX,int *currentmodel,int *nextmodel,
			  int maxsize,double *bestarss,int *gCOUNT,int IP,int nglmcall,int **bestmodels,
			  int delind,double *currentarss);

void DSA_PACK_getglmWT_excludeNA(int samplesize,double *glmWT,double *tempXdata,double *tempYdata,int msize,
				 int maxsize,int *NnonNA,int CENSOR,double *WTdata);

double DSA_PACK_getarss(int nobs,double *X,int nrow,int ncoef,double *Y,double *Weight,double *beta,int link);

==> DSA_2.0.2.tar.gz: DSA/src/dsa.h <==
#define epsiloncompare 1e-8
#define GLOBALg02tol 1e-6 
#define DSA_PACK_Mbase 0
#define DSA_PACK_Mlow 1
#define DSA_PACK_Mmedium 2
#define DSA_PACK_Mhigh 3
#define abs(a) (((a)>0)?(a):(-(a)))
#define max(a,b) (((a)>(b))?(a):(b))

#ifndef __HAS_userMlevel__ 
#define __HAS_userMlevel__ 

int DSA_PACK_userMlevel;

#endif 

void DSA_PACK_printmatrix(double *x, int nrow, int ncol);
void DSA_PACK_printmatrixl(int *x, int nrow, int ncol);
void DSA_PACK_printmatrix_to_file(double *x, int nrow, int ncol, char* f);

double DSA_PACK_getmin(double *x,int n);
void DSA_PACK_initialize_l(int *x,int n);
void DSA_PACK_initialize_d(double *x,int n);
int DSA_PACK_rowsumints(int *x,int nrow,int ncol,int whichrow);
int DSA_PACK_num_nonzero(int *x,int n);
int DSA_PACK_sumofints(int *x,int n);


void DSA_PACK_startAlgo(double *glmWT,double *PARA,double *SE,double *COV,
			double *RES,int *gCOUNT,int *gCONST,double *bestarss, double *Ydata, double *Xdata,
			int *sx,int **bestmodels,int *currentmodel,int *tempmodel,int *nextmodel,int *newterm,
			int *ithterm,double *tempterm,double *tempXdata,double *tempYdata,double *WTdata,
			int trainFlag,double *currentarss,int *nforced, int *forcedterms,
			double* new_coefficients,
			double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot,double *binWTdata);
		       

void DSA_PACK_getaverageCVrisks(int *gCOUNT,int *gCONST,int *sx,double *Xtrain,double *Ytrain,double *Xval,
				double *Yval,int **bestmodels,double *tempXtrain,double *tempYtrain,
				double *tempXval,double *tempYval,double *temptermtrain,
				double *temptermval,double *PARA,double *SE,double *COV,double *RES,
				double *glmWT,double *CVrisksbysplit,
				double *WTtrain,double *WTval,int nforced,int *tempmodel,
				double* new_coefficients,
				double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot,double *binWTtrain,double *binWTval);

int DSA_PACK_Sstep(int *gCOUNT,int *gCONST,double *bestarss,int **bestmodels,int *tempmodel,int *currentmodel,
		   int *nextmodel,int *newterm,double *Xdata,double *tempXdata,double *Ydata,double *tempYdata,
		   double *tempterm,int *sx,double *glmWT,double *PARA,double *SE,double *COV,
		   double *RES,int *ithterm,double *WTdata,int trainFlag,double *currentarss, int nforced,
		   double* new_coefficients,
		   double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot,double *binWTdata
		   );

int DSA_PACK_Astep(int *gCOUNT,int *gCONST,double *bestarss,int **bestmodels,int *tempmodel,int *currentmodel,
		   int *nextmodel,int *newterm,double *Xdata,double *tempXdata,double *Ydata,double *tempYdata,
		   double *tempterm,int *sx,double *glmWT,double *PARA,double *SE,double *COV,
		   double *RES,int *ithterm,double *WTdata,int trainFlag,double *currentarss,
		   double* new_coefficients,
		   double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot,double *binWTdata
		   );

int DSA_PACK_Dstep(int *gCOUNT,int *gCONST,double *bestarss,int **bestmodels,int *tempmodel,int *currentmodel,
		   int *nextmodel,int *newterm,double *Xdata,double *tempXdata,double *Ydata,double *tempYdata,
		   double *tempterm,int *sx,double *glmWT,double *PARA,double *SE,double *COV,
		   double *RES,double *WTdata,int trainFlag,double *currentarss,
		   int nforced,
		   double* new_coefficients,
		   double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot,double *binWTdata
		   );

void DSA_PACK_gettempXdata(int msize,int *tempmodel, int maxsize, int nvarX, int samplesize, double *tempXdata, 
			   double *Xdata, double *tempterm,double *tempYdata,double *Ydata);


void DSA_PACK_evaluatenewmodel(int *sx,int maxsize,int msize,int *tempmodel,int newterm_index,
			       int *changeindexset,int nvarX, int samplesize,double *tempXdata,
			       double *Xdata,double *tempterm, int CENSOR,double *glmWT,double *WTdata, 
			       int IP,double *tempYdata,double *Ydata,double *PARA,double *SE,double *COV,
			       double *RES, int *nglmcall, double *newrss,int *nextmodel,int inddel,int binind,
			       double* new_coefficients,
			       double* WX, double* Z, double* qraux, double* effects, double* work, int* pivot,double *binWTdata);



void DSA_PACK_checknewterm(int *orderint_in_newterm,int *sumofpow_in_newterm,int *is_newterm_unique,
			   int *newterm,int nvarX,int *tempmodel,int *ithterm,int maxsize,int newterm_index,
			   int addmove_notsubmove);

int DSA_PACK_istermunique(int *newterm,int *tempmodel,int *ithterm,int maxsize,int nvarX,int newterm_index,
			  int addmove_notsubmove,int orderint_in_newterm, int sumofpow_in_newterm);

int DSA_PACK_exportresult(double *oldrss,double newrss,int msize,int nvarX,int *currentmodel,int *nextmodel,
			  int maxsize,double *bestarss,int *gCOUNT,int IP,int nglmcall,int **bestmodels,
			  int delind,double *currentarss);

void DSA_PACK_getglmWT_excludeNA(int samplesize,double *glmWT,double *tempXdata,double *tempYdata,int msize,
				 int maxsize,int *NnonNA,int CENSOR,double *WTdata);

double DSA_PACK_getarss(int nobs,double *X,int nrow,int ncoef,double *Y,double *Weight,double *beta,int link,double *binWTdata);
